#! /usr/bin/env python

from lightflow import *

s = scene()

s.newInterface( "default",
		[ "trace-depth", 6,
		  "radiosity-depth", 0, 6,
		  "radiosity-sampling", "default",
		  "radiosity-samples", 64,
		  "radiosity-threshold", 0.1,
		  "radiosity-reuse-distance", 0.4, 0.01,
		  "photon-count", 1000000,
		  "photon-clustering-count", 1000, 100 ] )

s.lightOn( s.newLight( "point", [ "position", vector3( 5.0, -5.0, 4.0 ), "color", vector3( 400.0, 400.0, 400.0 ) ] ) )


plastic = s.newMaterial( "standard", [ "kc", vector3( 1, 1, 1 ), "kd", 0.5 ] )

glass = s.newMaterial( "general",
		       [ "fresnel", 1,
			 "IOR", 1.67,
			 "kdr", vector3( 0, 0, 0 ),
 			 "kdt", vector3( 0, 0, 0 ),
			 "ksr", vector3( 1, 1, 1 ), vector3( 1, 1, 1 ),
			 "kst", vector3( 1, 1, 1 ), vector3( 1, 1, 1 ),
			 "kr", vector3( 1, 1, 1 ),
			 "kt", vector3( 1, 1, 1 ),
			 "kd", 0.0,
			 "km", 0.03,
			 "shinyness", 1.0,
			 "transmission", 0,
			 "radiosity", 0,
			 "caustics", 1, 1 ] )


s.materialBegin( glass )

s.transformBegin( transform().translation( vector3( 0.0, 0.0, 0.8 ) ) )
s.transformBegin( transform().rotationAroundX( 3.141592 / 12 ) )
s.transformBegin( transform().rotationAroundZ( 3.141592 / 6 ) )

s.addObject( s.newObject( "box", [ "position", vector3(-1.2, -0.15, -0.15), vector3(1.2, 0.15, 0.15) ] ) )

s.transformEnd()
s.transformEnd()
s.transformEnd()

s.materialEnd()


s.materialBegin( plastic )

s.addObject( s.newObject( "disc", [ "radius", 10.0 ] ) )

s.materialEnd()



saver = s.newImager( "tga-saver", [ "file", "box.tga" ] )

s.imagerBegin( saver )

camera = s.newCamera( "pinhole", [ "eye", vector3( 0, -3, 3 ), "aim", vector3( 0, 0, 0 ) ] )

s.imagerEnd()

s.radiosity()

s.render( camera, 300, 300 )
