#! /usr/bin/env python

from lightflow import *

s = scene()

s.lightOn( s.newLight( "soft",
		       [ "position", vector3( 5.0, -5.0, 5.0 ),
			 "color", vector3( 400.0, 400.0, 400.0 ) ] ) )


blotchy = s.newPattern( "multifractal",
			[ "color",
			  0.0, vector3(0.1, 0.1, 0.1), vector3(0.1, 0.1, 0.1),
  			  1.0, vector3(1.0, 1.0, 1.0), vector3(1.0, 1.0, 1.0),
			  "basis", "sin",
			  "scale", 8.0,
			  "turbulence.omega", 0.3, 0.6,
			  "turbulence.octaves", 4] )

envmap  = s.newPattern( "envmap",
			[ "pattern", blotchy,
			  "center", vector3( 0, 0, 0 ),
			  "radius", 10.0,
			  "reflection", vector3( 0.8, 0.9, 1.0 ),
  			  "refraction", vector3( 0.2, 0.6, 1.0 ),
    			  "IOR", 1.67,
			  "fresnel", 1, 0.1, 0.1 ] )

bump = s.newPattern( "crackle",
		     [ "depth",
		       0.00, 0.0, 0.0,
		       0.80, 1.0, 1.0,
		       "scale", 1.00, # also 0.5 works well
		       "depth", 0.40,
		       "turbulence.amount", 0.3 ] )

glass = s.newMaterial( "general",
		       [ "fresnel", 1,
			 "IOR", 1.67,
			 "kdr", vector3( 0, 0, 0 ),
 			 "kdt", vector3( 0, 0, 0 ),
			 "ksr", vector3( 0.8, 0.9, 1 ), vector3( 1, 0.4, 1 ),
			 "ka", vector3( 1, 1, 1 ),
			 "ka", envmap,
			 "kd", 0.0,
			 "km", 0.1,
			 "shinyness", 0.95,
			 "displacement", bump,
			 "radiosity", 0 ] )

plastic = s.newMaterial( "standard",
			 [ "ka", vector3( 0.1, 0.1, 0.1 ),
			   "kc", vector3( 1.0, 1.0, 1.0 ),
			   "kd", 0.8,
			   "km", 0.1,
			   "visibility", 1 ] )


s.materialBegin( glass )

sphere = s.newObject( "sphere",
		     [ "radius", 1.3 ] )

s.addObject( s.newObject( "surface-engine",
			  [ "surfaces", sphere,
			    "tolerance", 0.05, 0.1, 0.05,
			    "caching", 8192 ] ) )

s.materialEnd()


saver = s.newImager( "tga-saver", [ "file", "gem2.tga" ] )

s.imagerBegin( saver )

camera = s.newCamera( "pinhole", [ "eye", vector3( 0, -4, 3 ), "aim", vector3( 0, 0, 0 ) ] )

s.imagerEnd()

s.render( camera, 300, 300 )
