#! /usr/bin/env python

from lightflow import *

s = scene()

s.lightOn( s.newLight( "soft",
		       [ "position", vector3( 5.0, -5.0, 5.0 ),
			 "color", vector3( 400.0, 400.0, 400.0 ) ] ) )


blotchy = s.newPattern( "multifractal",
			[ "color",
			  0.0, vector3(0.2, 0.2, 0.2), vector3(0.2, 0.2, 0.2),
  			  1.0, vector3(1.0, 1.0, 1.0), vector3(1.0, 1.0, 1.0),
			  "basis", "sin",
			  "scale", 8.0,
			  "turbulence.omega", 0.3, 0.6,
			  "turbulence.octaves", 2] )

bump = s.newPattern( "multifractal",
		     [ "depth", 0.2,
		       "basis", "crater",
		       "scale", 0.8,
		       "turbulence.omega", 0.3, 0.6,
		       "turbulence.octaves", 1] )

crackle1 = s.newPattern( "crackle",
			[ "scale", 0.7,
			  "color",
			  0.10, vector3( 0.0, 0.0, 0.0 ), vector3( 0.0, 0.0, 0.0 ),
			  0.15, vector3( 0.8, 1.0, 1.0 ), vector3( 0.8, 1.0, 1.0 ),
			  "turbulence.amount", 0.0, # 0.1
			  "turbulence.octaves", 2 ] )

crackle2 = s.newPattern( "crackle",
			[ "scale", 0.7,
			  "color",
			  0.10, vector3( 1.0, 1.0, 1.0 ), vector3( 1.0, 1.0, 1.0 ),
			  0.15, vector3( 0.0, 0.0, 0.0 ), vector3( 0.0, 0.0, 0.0 ),
			  "value",
			  0.10, 0.5, 0.5,
			  0.15, 0.0, 0.0,
			  "turbulence.amount", 0.0, # 0.1
			  "turbulence.octaves", 2 ] )

envmap  = s.newPattern( "envmap",
			[ "pattern", blotchy,
			  "center", vector3( 0, 0, 0 ),
			  "radius", 10.0,
			  "reflection", vector3( 1, 1, 1 ),
  			  "reflection", crackle1,
			  "refraction", vector3( 1, 1, 1 ),
  			  "refraction", crackle1,
    			  "IOR", 1.7,
			  "fresnel", 1 ] )

glass = s.newMaterial( "general",
		       [ "fresnel", 1,
			 "IOR", 1.67,
			 "kdr", vector3( 1, 1, 1 ),
			 "kdr", crackle2,
 			 "kdt", vector3( 0, 0, 0 ),
			 "ksr", vector3( 0.8, 1.0, 0.9 ), vector3( 0.4, 1, 1 ),
			 "ka", vector3( 1, 1, 1 ),
			 "ka", envmap,
			 "kd", 1.0,
			 "kd", crackle2,
			 "km", 0.1,
			 "shinyness", 0.95,
			 "displacement", bump,
			 "radiosity", 0 ] )

plastic = s.newMaterial( "standard",
			 [ "ka", vector3( 0.1, 0.1, 0.1 ),
			   "kc", vector3( 1.0, 1.0, 1.0 ),
			   "kd", 0.8,
			   "km", 0.1,
			   "visibility", 1 ] )


s.materialBegin( glass )

sphere = s.newObject( "sphere",
		     [ "radius", 1.3 ] )

s.addObject( s.newObject( "surface-engine",
			  [ "surfaces", sphere,
			    "tolerance", 0.1, 0.1, 0.05,
			    "caching", 8192 ] ) )

s.materialEnd()


saver = s.newImager( "tga-saver", [ "file", "gem4.tga" ] )

s.imagerBegin( saver )

camera = s.newCamera( "pinhole", [ "eye", vector3( 0, -4, 3 ), "aim", vector3( 0, 0, 0 ) ] )

s.imagerEnd()

s.render( camera, 300, 300 )
