#! /usr/bin/env python

from lightflow import *

s = scene()

s.lightOn( s.newLight( "point", [ "position", vector3( 5.0, -5.0, 4.0 ), "color", vector3( 300.0, 300.0, 300.0 ) ] ) )


scales = s.newPattern( "scales",
		       [ "scale", 0.3,
			 "depth", 0.2 ] )

blotchy = s.newPattern( "multifractal",
			[ "color",
			  0.0, vector3(0.3, 0.3, 0.3), vector3(0.3, 0.3, 0.3),
  			  1.0, vector3(1.0, 1.0, 1.0), vector3(1.0, 1.0, 1.0),
			  "basis", "sin",
			  "scale", 10.0,
			  "turbulence.omega", 0.3, 0.5,
			  "turbulence.octaves", 3] )

envmap  = s.newPattern( "envmap",
			[ "pattern", blotchy,
			  "center", vector3( 0, 0, 0 ),
			  "radius", 10.0,
			  "reflection", vector3( 0.9, 0.9, 1 ),
			  "refraction", vector3( 0.0, 0.0, 0 ),
    			  "IOR", 8.0,
			  "fresnel", 1 ] )

bump = s.newPattern( "multifractal",
		     [ "basis", "ridged",
		       "scale", 0.3,
		       "depth", 0.01,
		       "turbulence.omega", 0.4, 0.7,
		       "turbulence.octaves", 3 ] )

mix =  s.newPattern( "compose",
		     [ "patterns", scales, bump ] )


metal = s.newMaterial( "general",
		       [ "fresnel", 1,
			 "IOR", 8.0,
			 "ka", vector3( 1, 1, 1 ),
			 "ka", envmap,
			 "kdr", vector3( 0.9, 0.9, 1 ),
			 "ksr", vector3( 0.9, 0.9, 1 ), vector3( 0.9, 0.6, 1.0 ),
			 "kd", 0.00,
			 "km", 0.08,
			 "shinyness", 0.95,
			 "displacement", mix,
			 "radiosity", 0 ] )


s.materialBegin( metal )

sphere = s.newObject( "sphere", [ "radius", 1.0 ] )

s.addObject( s.newObject( "surface-engine",
			  [ "surfaces", sphere,
			    "tolerance", 0.01, 0.1, 0.05,
			    "caching", 8192 ] ) )

s.materialEnd()


saver = s.newImager( "tga-saver", [ "file", "scales.tga" ] )

s.imagerBegin( saver )

camera = s.newCamera( "pinhole", [ "eye", vector3( 0, -4, 0 ), "aim", vector3( 0, 0, 0 ) ] )

s.imagerEnd()

s.render( camera, 300, 300 )
