#! /usr/bin/env python

from lightflow import *

s = scene()

s.newInterface( "default",
		[ "trace-depth", 6,
		  "radiosity-depth", 0, 6,
		  "radiosity-sampling", "default",
		  "radiosity-samples", 64,
		  "radiosity-threshold", 0.1,
		  "radiosity-reuse-distance", 0.4, 0.01,
		  "photon-count", 1000000,
		  "photon-clustering-count", 1000, 100 ] )


s.lightOn( s.newLight( "soft", [ "position", vector3( 5.0, -4.0, 7.0 ), "color", vector3( 500.0, 500.0, 500.0 ) ] ) )


scales = s.newPattern( "scales",
		       [ "color",
			 0.3, vector3(1.0, 0.4, 1.0), vector3(1.0, 0.4, 1.0),
 			 1.0, vector3(0.4, 0.5, 1.0), vector3(0.4, 0.5, 1.0),
			 "scale", 0.8,
			 "depth", 0.2 ] )

plastic = s.newMaterial( "standard",
			 [ "kc", vector3( 1, 1, 1 ),
			   "kc", scales,
			   "kd", 0.8,
			   "displacement", scales ] )

glass = s.newMaterial( "general",
		       [ "fresnel", 1,
			 "IOR", 1.1,
			 "kdr", vector3( 0, 0, 0 ),
 			 "kdt", vector3( 0, 0, 0 ),
			 "ksr", vector3( 1, 1, 1 ), vector3( 1, 1, 1 ),
			 "kst", vector3( 1, 1, 1 ), vector3( 1, 1, 1 ),
			 "kr", vector3( 1, 1, 1 ),
			 "kt", vector3( 1, 1, 1 ),
			 "kd", 0.0,
			 "km", 0.01,
			 "shinyness", 1.0,
			 "transmission", 0,
			 "radiosity", 0,
			 "caustics", 1, 1 ] )


s.materialBegin( glass )

s.transformBegin( transform().translation( vector3( 0.0, 0.0, 0.8 ) ) )

s.addObject( s.newObject( "sphere", [ "radius", 0.8 ] ) )

s.transformEnd()

s.materialEnd()


s.materialBegin( plastic )

s.addObject( s.newObject( "disc", [ "radius", 10.0 ] ) )

s.materialEnd()



saver = s.newImager( "tga-saver", [ "file", "sphere.tga" ] )

s.imagerBegin( saver )

camera = s.newCamera( "pinhole", [ "eye", vector3( 0, -3, 3 ), "aim", vector3( 0, 0, 0.5 ) ] )

s.imagerEnd()


s.radiosity()

s.render( camera, 300, 300 )
